/*
  Copyright 2003 John Knottenbelt
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
 
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
*/

#include "configfile.h"
#include "stringutil.h"
#include <fstream>
#include <iostream>

ConfigFile::ConfigFile()
{
}

void ConfigFile::clear()
{
  data.clear();
}

bool ConfigFile::read(const std::string &file)
{
  std::ifstream input(file.c_str());
  if (!input)
    return false;

  std::string line;
  int lineno = 0;

  while (getline(input, line)) {
    lineno++;
    line = stripTrailingWS(stripLeadingWS(stripLineComment(line)));

    if (line == "")
      continue;

    std::string::size_type pos = line.find('=');
    if (pos == std::string::npos) {
      std::cerr << "Warning: error reading configuration file, no '=' found on line " 
		<< lineno << std::endl;
      continue;
    }

    std::string key = stripTrailingWS(line.substr(0, pos));
    std::string value = stripLeadingWS(line.substr(pos + 1));

    data[key] = value;
  }

  input.close();
  return true;
}

void ConfigFile::set(const std::string &key, const std::string &value)
{
  data[key] = value;
}

std::string ConfigFile::get(const std::string &key) 
{
  return data[key];
}
