/*
  Copyright 2003 John Knottenbelt
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
 
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
*/

#include "config.h"
#include "select.h"

#include <cstdlib>

Select::Select() {
  clearFDs();
};

void Select::clearFDs() {
  FD_ZERO(&readfds);
  FD_ZERO(&writefds);
  FD_ZERO(&exceptfds);
  maxFD = -1;
  tv_sec = -1;
  tv_usec = -1;
};

void Select::addReadFD(int fd) {
  FD_SET(fd, &readfds);
  setMaxFD(fd);
};

void Select::addWriteFD(int fd) {
  FD_SET(fd, &writefds);
  setMaxFD(fd);
};

void Select::addExceptFD(int fd) {
  FD_SET(fd, &exceptfds);
  setMaxFD(fd);
};

void Select::addAlarm(long sec, long usec)
{
  if (tv_sec == -1 && tv_usec == -1) {
    tv_sec = sec;
    tv_usec = usec;
  }
  else if (sec < tv_sec) {
    tv_sec = sec;
    tv_usec = usec;
  }
  else if (sec == tv_sec && usec < tv_usec) 
    tv_usec = usec;
}

int Select::wait() {
  
  if (tv_sec == -1 && tv_usec == -1)
    return select(maxFD + 1, &readfds, &writefds, &exceptfds, NULL);

  struct timeval tv;
  tv.tv_sec = tv_sec;
  tv.tv_usec = tv_usec;

  return select(maxFD + 1, &readfds, &writefds, &exceptfds, &tv);
};

bool Select::readyToRead(int fd) const {
  return FD_ISSET(fd, &readfds);
};

bool Select::readyToWrite(int fd) const {
  return FD_ISSET(fd, &writefds);
};

bool Select::readyToExcept(int fd) const {
  return FD_ISSET(fd, &exceptfds);
};

void Select::setMaxFD(int fd) {
  if (fd > maxFD)
    maxFD = fd;
}
